@@ -4,7 +4,6 @@ from .admin_action import AdminAction
 from .block_action import BlockAction
 from .leave_action import LeaveAction
 from .lfg_action import LookingForGameAction
-from .record_action import RecordAction
 from .score_action import ScoreAction
 from .tasks_action import TasksAction
 from .verify_action import VerifyAction
@@ -15,7 +14,6 @@ __all__ = [
     "BlockAction",
     "LeaveAction",
     "LookingForGameAction",
-    "RecordAction",
     "ScoreAction",
     "TasksAction",
     "VerifyAction",
