@@ -11,9 +11,9 @@ from cachetools import TTLCache
 from ddtrace.trace import tracer
 from discord.ext.commands import AutoShardedBot, CommandError, CommandNotFound, Context
 
-from . import spelltable, tablestream
 from .database import db_session_manager, initialize_connection
 from .enums import GameService
+from .integrations import convoke, spelltable, tablestream
 from .metrics import setup_ignored_errors, setup_metrics
 from .models import GameLinkDetails
 from .operations import safe_delete_message
@@ -52,6 +52,7 @@ class SpellBot(AutoShardedBot):
         self.mock_games = mock_games
         self.create_connection = create_connection
         self.guild_locks = TTLCache[int, asyncio.Lock](maxsize=100, ttl=3600)  # 1 hr
+        self.supporters: set[int] = set()
 
     async def on_ready(self) -> None:  # pragma: no cover
         logger.info("client ready")
@@ -94,6 +95,9 @@ class SpellBot(AutoShardedBot):
             case GameService.SPELLTABLE.value:
                 link = await spelltable.generate_link(game)
                 return GameLinkDetails(link)
+            case GameService.CONVOKE.value:
+                details = await convoke.generate_link(game)
+                return GameLinkDetails(*details)
             case GameService.TABLE_STREAM.value:
                 details = await tablestream.generate_link(game)
                 return GameLinkDetails(*details)
