@@ -1,4 +1,7 @@
+from __future__ import annotations
+
 import logging
+from typing import TYPE_CHECKING
 
 import discord
 from ddtrace.trace import tracer
@@ -6,7 +9,6 @@ from discord import app_commands
 from discord.app_commands import Choice
 from discord.ext import commands
 
-from spellbot import SpellBot
 from spellbot.actions.lfg_action import LookingForGameAction
 from spellbot.enums import GAME_BRACKET_ORDER, GAME_FORMAT_ORDER, GAME_SERVICE_ORDER
 from spellbot.metrics import add_span_context
@@ -14,6 +16,9 @@ from spellbot.operations import safe_defer_interaction
 from spellbot.settings import settings
 from spellbot.utils import for_all_callbacks, is_guild
 
+if TYPE_CHECKING:
+    from spellbot import SpellBot
+
 logger = logging.getLogger(__name__)
 
 
@@ -35,15 +40,15 @@ class LookingForGameCog(commands.Cog):
     @app_commands.describe(rules="Any additional rules or requests for this game.")
     @app_commands.describe(service="What service do you want to use to play this game?")
     @app_commands.choices(
-        service=[Choice(name=str(service), value=service.value) for service in GAME_SERVICE_ORDER]
+        service=[Choice(name=str(service), value=service.value) for service in GAME_SERVICE_ORDER],
     )
     @app_commands.describe(format="What game format do you want to play?")
     @app_commands.choices(
-        format=[Choice(name=str(format), value=format.value) for format in GAME_FORMAT_ORDER]
+        format=[Choice(name=str(format), value=format.value) for format in GAME_FORMAT_ORDER],
     )
     @app_commands.describe(bracket="What commander bracket do you want to play?")
     @app_commands.choices(
-        bracket=[Choice(name=str(bracket), value=bracket.value) for bracket in GAME_BRACKET_ORDER]
+        bracket=[Choice(name=str(bracket), value=bracket.value) for bracket in GAME_BRACKET_ORDER],
     )
     @tracer.wrap(name="interaction", resource="lfg")
     async def lfg(
