@@ -1,10 +1,12 @@
+from __future__ import annotations
+
 import logging
 from inspect import cleandoc
+from typing import TYPE_CHECKING
 
 from ddtrace.trace import tracer
 from discord.ext import commands
 
-from spellbot import SpellBot
 from spellbot.actions.base_action import handle_exception
 from spellbot.database import db_session_manager
 from spellbot.metrics import add_span_context
@@ -13,6 +15,9 @@ from spellbot.services import ServicesRegistry
 from spellbot.settings import settings
 from spellbot.utils import for_all_callbacks, load_extensions
 
+if TYPE_CHECKING:
+    from spellbot import SpellBot
+
 logger = logging.getLogger(__name__)
 
 
@@ -133,6 +138,7 @@ class OwnerCog(commands.Cog):
                     shards:   {self.bot.shard_count}
                     guilds:   {len(self.bot.guilds)}
                     users:    {len(self.bot.users)}
+                    patrons:  {self.bot.supporters}
                     ```
                 """,
             ),
