@@ -1,15 +1,21 @@
+from __future__ import annotations
+
 import asyncio
 import logging
+from typing import TYPE_CHECKING
 
 from ddtrace.trace import tracer
-from discord import Client
 from discord.ext import commands, tasks
 
-from spellbot import SpellBot
 from spellbot.actions import TasksAction
 from spellbot.environment import running_in_pytest
 from spellbot.settings import settings
 
+if TYPE_CHECKING:
+    from discord import Client
+
+    from spellbot import SpellBot
+
 logger = logging.getLogger(__name__)
 
 WAIT_UNTIL_READY_TIMEOUT = 900.0  # 15 minutes
@@ -52,6 +58,7 @@ class TasksCog(commands.Cog):  # pragma: no cover
         if not running_in_pytest():
             self.cleanup_old_voice_channels.start()
             self.expire_inactive_games.start()
+            self.patreon_sync.start()
 
     @tasks.loop(minutes=settings.VOICE_CLEANUP_LOOP_M)
     async def cleanup_old_voice_channels(self) -> None:
@@ -79,6 +86,19 @@ class TasksCog(commands.Cog):  # pragma: no cover
     async def before_expire_inactive_games(self) -> None:
         await wait_until_ready(self.bot)
 
+    @tasks.loop(minutes=settings.PATREON_SYNC_LOOP_M)
+    async def patreon_sync(self) -> None:
+        try:
+            with tracer.trace(name="command", resource="patreon_sync"):
+                async with TasksAction.create(self.bot) as action:
+                    await action.patreon_sync()
+        except BaseException:  # Catch EVERYTHING so tasks don't die
+            logger.exception("error: exception in task cog")
+
+    @patreon_sync.before_loop
+    async def before_patreon_sync(self) -> None:
+        await wait_until_ready(self.bot)
+
 
 async def setup(bot: SpellBot) -> None:  # pragma: no cover
     await bot.add_cog(TasksCog(bot), guild=settings.GUILD_OBJECT)
