@@ -20,6 +20,8 @@ class Settings:
         "BOT_INVITE_LINK",
         "BOT_TOKEN",
         "CONTENT_ROOT",
+        "CONVOKE_API_KEY",
+        "CONVOKE_ROOT",
         "DATABASE_ECHO",
         "DATABASE_URL",
         "DD_API_KEY",
@@ -35,6 +37,10 @@ class Settings:
         "LOCALE",
         "MAX_PENDING_GAMES",
         "MOD_PREFIX",
+        "OWNER_XID",
+        "PATREON_CAMPAIGN",
+        "PATREON_SYNC_LOOP_M",
+        "PATREON_TOKEN",
         "PENDING_EMBED_COLOR",
         "PORT",
         "REDIS_URL",
@@ -57,7 +63,7 @@ class Settings:
         "guild_xid",
     )
 
-    def __init__(self, guild_xid: int | None = None) -> None:
+    def __init__(self, guild_xid: int | None = None) -> None:  # noqa: PLR0915
         self.guild_xid = guild_xid
 
         # content
@@ -72,6 +78,7 @@ class Settings:
         self.HOST = getenv("HOST") or "localhost"
         self.DEBUG_GUILD = getenv("DEBUG_GUILD")
         self.API_BASE_URL = getenv("API_BASE_URL", "https://bot.spellbot.io")
+        self.OWNER_XID = getenv("OWNER_XID")
 
         # datadog
         self.DD_API_KEY = getenv("DD_API_KEY")
@@ -114,6 +121,10 @@ class Settings:
         self.TABLESTREAM_CREATE = f"{self.TABLESTREAM_ROOT}/create-room"
         self.TABLESTREAM_AUTH_KEY = getenv("TABLESTREAM_AUTH_KEY")
 
+        # convoke
+        self.CONVOKE_ROOT = "https://api.convoke.games/api"
+        self.CONVOKE_API_KEY = getenv("CONVOKE_API_KEY")
+
         # configuration
         self.BOT_INVITE_LINK = (
             r"https://discordapp.com/api/oauth2/authorize"
@@ -139,6 +150,11 @@ class Settings:
         self.EXPIRE_GAMES_LOOP_M = 10  # 10 minutes
         self.EXPIRE_TIME_M = 45  # 45 minutes
 
+        # patreon integration
+        self.PATREON_TOKEN = getenv("PATREON_TOKEN")
+        self.PATREON_CAMPAIGN = getenv("PATREON_CAMPAIGN")
+        self.PATREON_SYNC_LOOP_M = 60  # 60 minutes
+
     def workaround_over_eager_caching(self, url: str) -> str:
         return f"{url}?{datetime.now(tz=UTC).date().strftime('%Y-%m-%d')}"
 
