@@ -54,6 +54,12 @@ class TestSpellBot(BaseMixin):
                 "tablestream.generate_link",
                 id="tablestream",
             ),
+            pytest.param(
+                False,
+                {"service": GameService.CONVOKE.value},
+                "convoke.generate_link",
+                id="convoke",
+            ),
             pytest.param(
                 False,
                 {"service": GameService.NOT_ANY.value},
